# Generated by Django 5.0.2 on 2024-03-08 10:52

from django.db import migrations
from django.db.backends.base.schema import BaseDatabaseSchemaEditor
from django.db.migrations.state import StateApps
from django.db.models import Value

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar

OLD_NAME = '"Europe/Kiev"'
NEW_NAME = '"Europe/Kyiv"'


def backfill_ukraine_timezone_name(
    apps: StateApps, schema_editor: BaseDatabaseSchemaEditor
) -> None:
    UserOption = apps.get_model("sentry", "UserOption")

    user_options = UserOption.objects.filter(key="timezone", value=Value(OLD_NAME))
    for user_option in RangeQuerySetWrapperWithProgressBar(user_options):
        user_option.value = Value(NEW_NAME)
        user_option.save(update_fields=["value"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production. For
    # the most part, this should only be used for operations where it's safe to run the migration
    # after your code has deployed. So this should not be used for most operations that alter the
    # schema of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually by ops so that they can
    #   be monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   have ops run this and not block the deploy. Note that while adding an index is a schema
    #   change, it's completely safe to run the operation after the code has deployed.
    is_post_deployment = False

    dependencies = [
        ("sentry", "0671_enforce_unqiue_active_incidents"),
    ]

    operations = [
        migrations.RunPython(
            backfill_ukraine_timezone_name,
            reverse_code=migrations.RunPython.noop,
            hints={"tables": ["sentry_useroption"]},
        )
    ]
