# Generated by Django 5.0.3 on 2024-04-18 15:49
import click
from django.apps.registry import Apps
from django.db import migrations
from django.db.backends.base.schema import BaseDatabaseSchemaEditor
from django.db.models import Q

from sentry.new_migrations.migrations import CheckedMigration
from sentry.utils.query import RangeQuerySetWrapperWithProgressBar


def backfill_alertrule_owners(apps: Apps, schema_editor: BaseDatabaseSchemaEditor) -> None:
    AlertRule = apps.get_model("sentry", "AlertRule")
    Actor = apps.get_model("sentry", "Actor")

    expr = Q(user_id__isnull=True) | Q(team_id__isnull=True)
    # AlertRule defines a custom default manager.
    rules = AlertRule.objects_with_snapshots.filter(owner_id__isnull=False).filter(expr)
    for rule in RangeQuerySetWrapperWithProgressBar(rules):
        actor = Actor.objects.get(id=rule.owner_id)
        if actor.user_id:
            rule.user_id = actor.user_id
        elif actor.team_id:
            rule.team_id = actor.team_id
        else:
            click.echo("Actor was neither a user or team")
        rule.save(update_fields=["team_id", "user_id"])


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production.
    # This should only be used for operations where it's safe to run the migration after your
    # code has deployed. So this should not be used for most operations that alter the schema
    # of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually so that they can be
    #   monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   run this outside deployments so that we don't block them. Note that while adding an index
    #   is a schema change, it's completely safe to run the operation after the code has deployed.
    # Once deployed, run these manually via: https://develop.sentry.dev/database-migrations/#migration-deployment

    is_post_deployment = True

    dependencies = [
        ("sentry", "0700_drop_fileid_controlavatar"),
    ]

    operations = [
        migrations.RunPython(
            backfill_alertrule_owners,
            reverse_code=migrations.RunPython.noop,
            hints={"tables": ["sentry_alertrule", "sentry_actor"]},
        )
    ]
