# Generated by Django 5.0.6 on 2024-06-20 22:17

import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models

import sentry.db.models.fields.bounded
import sentry.db.models.fields.foreignkey
from sentry.new_migrations.migrations import CheckedMigration


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production.
    # This should only be used for operations where it's safe to run the migration after your
    # code has deployed. So this should not be used for most operations that alter the schema
    # of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually so that they can be
    #   monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   run this outside deployments so that we don't block them. Note that while adding an index
    #   is a schema change, it's completely safe to run the operation after the code has deployed.
    # Once deployed, run these manually via: https://develop.sentry.dev/database-migrations/#migration-deployment

    is_post_deployment = False

    initial = True

    dependencies = [
        ("remote_subscriptions", "0001_remote_subscription"),
        ("sentry", "0731_add_insight_project_flags"),
    ]

    operations = [
        migrations.CreateModel(
            name="UptimeSubscription",
            fields=[
                (
                    "id",
                    sentry.db.models.fields.bounded.BoundedBigAutoField(
                        primary_key=True, serialize=False
                    ),
                ),
                (
                    "remote_subscription",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="remote_subscriptions.remotesubscription",
                        unique=True,
                    ),
                ),
                ("url", models.CharField(max_length=255)),
                ("interval_seconds", models.IntegerField()),
                ("timeout_ms", models.IntegerField()),
                ("date_updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("date_added", models.DateTimeField(default=django.utils.timezone.now, null=True)),
            ],
            options={
                "db_table": "uptime_uptimesubscription",
            },
        ),
        migrations.CreateModel(
            name="ProjectUptimeSubscription",
            fields=[
                (
                    "id",
                    sentry.db.models.fields.bounded.BoundedBigAutoField(
                        primary_key=True, serialize=False
                    ),
                ),
                (
                    "project",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="sentry.project"
                    ),
                ),
                (
                    "uptime_subscription",
                    sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="uptime.uptimesubscription"
                    ),
                ),
                ("date_updated", models.DateTimeField(default=django.utils.timezone.now)),
                ("date_added", models.DateTimeField(default=django.utils.timezone.now, null=True)),
            ],
            options={
                "db_table": "uptime_projectuptimesubscription",
            },
        ),
        migrations.AddConstraint(
            model_name="uptimesubscription",
            constraint=models.UniqueConstraint(
                fields=("url", "interval_seconds"),
                name="uptime_uptimesubscription_unique_url_check",
            ),
        ),
        migrations.AddConstraint(
            model_name="projectuptimesubscription",
            constraint=models.UniqueConstraint(
                fields=("project_id", "uptime_subscription"),
                name="uptime_projectuptimesubscription_unique_project_subscription",
            ),
        ),
    ]
