# Generated by Django 5.0.6 on 2024-06-21 17:10

import django.db.models.deletion
from django.db import migrations, models

import sentry.db.models.fields.foreignkey
from sentry.new_migrations.migrations import CheckedMigration


class Migration(CheckedMigration):
    # This flag is used to mark that a migration shouldn't be automatically run in production.
    # This should only be used for operations where it's safe to run the migration after your
    # code has deployed. So this should not be used for most operations that alter the schema
    # of a table.
    # Here are some things that make sense to mark as post deployment:
    # - Large data migrations. Typically we want these to be run manually so that they can be
    #   monitored and not block the deploy for a long period of time while they run.
    # - Adding indexes to large tables. Since this can take a long time, we'd generally prefer to
    #   run this outside deployments so that we don't block them. Note that while adding an index
    #   is a schema change, it's completely safe to run the operation after the code has deployed.
    # Once deployed, run these manually via: https://develop.sentry.dev/database-migrations/#migration-deployment

    is_post_deployment = False

    dependencies = [
        ("uptime", "0001_uptime_subscriptions"),
        ("remote_subscriptions", "0001_remote_subscription"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            state_operations=[
                migrations.RemoveField(
                    model_name="uptimesubscription",
                    name="remote_subscription",
                ),
                migrations.AddField(
                    model_name="uptimesubscription",
                    name="type",
                    field=models.TextField(),
                    preserve_default=False,
                ),
                migrations.AddField(
                    model_name="uptimesubscription",
                    name="status",
                    field=models.SmallIntegerField(db_index=True, default=0),
                ),
            ],
            database_operations=[
                migrations.AlterField(
                    model_name="uptimesubscription",
                    name="remote_subscription",
                    field=sentry.db.models.fields.foreignkey.FlexibleForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="remote_subscriptions.remotesubscription",
                        unique=True,
                    ),
                ),
                migrations.RunSQL(
                    """
                    ALTER TABLE "uptime_uptimesubscription" ADD COLUMN "type" text NOT NULL;
                    """,
                    reverse_sql="""
                        ALTER TABLE "uptime_uptimesubscription" DROP COLUMN "type";
                        """,
                    hints={"tables": ["uptime_uptimesubscription"]},
                ),
                migrations.RunSQL(
                    """
                    ALTER TABLE "uptime_uptimesubscription" ADD COLUMN "status" smallint NOT NULL DEFAULT 0;
                    """,
                    reverse_sql="""
                        ALTER TABLE "uptime_uptimesubscription" DROP COLUMN "status";
                        """,
                    hints={"tables": ["uptime_uptimesubscription"]},
                ),
            ],
        ),
        migrations.AddField(
            model_name="uptimesubscription",
            name="subscription_id",
            field=models.TextField(null=True, unique=True),
        ),
    ]
